@@ -1,19 +1,44 @@
 use strict;
 use warnings;
 package Software::License::Artistic_2_0;
+BEGIN {
+  $Software::License::Artistic_2_0::VERSION = '0.101370';
+}
 use base 'Software::License';
+# ABSTRACT: The Artistic License 2.0
+
+sub name { 'The Artistic License 2.0' }
+sub url  { 'http://www.perlfoundation.org/artistic_license_2_0' }
+sub meta_name  { 'artistic_2' }
+sub meta2_name { 'artistic_2_0' }
+
+1;
+
+
+=pod
 
 =head1 NAME
 
 Software::License::Artistic_2_0 - The Artistic License 2.0
 
+=head1 VERSION
+
+version 0.101370
+
+=head1 AUTHOR
+
+  Ricardo Signes <rjbs@cpan.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2010 by Ricardo Signes.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
 
-sub name { 'The Artistic License 2.0' }
-sub url  { 'http://www.perlfoundation.org/artistic_license_2_0' }
-sub meta_name { 'artistic_2' }
 
-1;
 __DATA__
 __LICENSE__
 		       The Artistic License 2.0
