@@ -1,19 +1,18 @@
 use strict;
 use warnings;
 package Software::License::OpenSSL;
+BEGIN {
+  $Software::License::OpenSSL::VERSION = '0.101370';
+}
 use base 'Software::License';
-
-=head1 NAME
-
-Software::License::OpenSSL - The OpenSSL License
-
-=cut
+# ABSTRACT: The OpenSSL License
 
 require Software::License::SSLeay;
 
 sub name { 'OpenSSL License' }
 sub url  { 'http://www.openssl.org/source/license.html' }
-sub meta_name { 'unrestricted' }
+sub meta_name  { 'open_source' }
+sub meta2_name { 'openssl' }
 
 sub _ssleay {
   my ($self) = @_;
@@ -24,6 +23,32 @@ sub _ssleay {
 }
 
 1;
+
+
+=pod
+
+=head1 NAME
+
+Software::License::OpenSSL - The OpenSSL License
+
+=head1 VERSION
+
+version 0.101370
+
+=head1 AUTHOR
+
+  Ricardo Signes <rjbs@cpan.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2010 by Ricardo Signes.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
+
+
 __DATA__
 __LICENSE__
   LICENSE ISSUES
