@@ -1,18 +1,45 @@
 use strict;
 use warnings;
 package Software::License::Sun;
+BEGIN {
+  $Software::License::Sun::VERSION = '0.101370';
+}
 use base 'Software::License';
+# ABSTRACT: Sun Internet Standards Source License (SISSL)
+
+sub name { 'Sun Internet Standards Source License (SISSL)' }
+sub url  { 'http://www.openoffice.org/licenses/sissl_license.html' }
+
+sub meta_name  { 'open_source' }
+sub meta2_name { 'sun' }
+
+1;
+
+
+=pod
 
 =head1 NAME
 
 Software::License::Sun - Sun Internet Standards Source License (SISSL)
 
+=head1 VERSION
+
+version 0.101370
+
+=head1 AUTHOR
+
+  Ricardo Signes <rjbs@cpan.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2010 by Ricardo Signes.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
 
-sub name { 'Sun Internet Standards Source License (SISSL)' }
-sub url  { 'http://www.openoffice.org/licenses/sissl_license.html' }
 
-1;
 __DATA__
 __LICENSE__
 Sun Internet Standards Source License (SISSL)
